@@ -25,18 +25,4 @@
 #' @format An \code{sf} object.
 #' @examples
 #' example_sf_point
-"example_sf_point"
-
-#' @title Example stars object.
-#' @description Example stars object.
-#' @format An \code{stars} object.
-#' @examples
-#' example_stars
-"example_stars"
-
-#' @title Example stars object 2.
-#' @description Example stars object.
-#' @format An \code{stars} object.
-#' @examples
-#' example_stars_2
-"example_stars_2"
\ No newline at end of file
+"example_sf_point"
\ No newline at end of file
