@@ -214,8 +214,8 @@ ggplot_point <- function(data,
 #' @param y_zero_line TRUE or FALSE whether to add a zero reference line to the y axis. TRUE if there are positive and negative values in y_var. Otherwise defaults to FALSE.
 #' @param col_labels_dp Select the appropriate number of decimal places for numeric variable auto legend labels. Defaults to 1.
 #' @param col_labels Adjust the colour scale labels through a vector.
-#' @param col_labels_ncol The number of columns in the legend. 
-#' @param col_labels_nrow The number of rows in the legend.
+#' @param col_legend_ncol The number of columns in the legend. 
+#' @param col_legend_nrow The number of rows in the legend.
 #' @param col_title Colour title string for the legend. Defaults to NULL.
 #' @param col_title_wrap Number of characters to wrap the colour title to. Defaults to 25. Not applicable where mobile equals TRUE.
 #' @param caption Caption title string. Defaults to NULL.
@@ -266,8 +266,8 @@ ggplot_point_col <-
            col_title = "",
            caption = NULL,
            col_labels = NULL,
-           col_labels_ncol = NULL,
-           col_labels_nrow = NULL,
+           col_legend_ncol = NULL,
+           col_legend_nrow = NULL,
            col_labels_dp = 1,
            font_family = "Helvetica",
            font_size_title = NULL,
@@ -308,7 +308,7 @@ ggplot_point_col <-
           if (dplyr::first(col_cuts) != 0) warning("The first element of the col_cuts vector generally always be 0")
           if (dplyr::last(col_cuts) != 1) warning("The last element of the col_cuts vector should generally be 1")
         }  
-        col_cuts <- quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
+        col_cuts <- stats::quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
         if (anyDuplicated(col_cuts) > 0) stop("col_cuts do not provide unique breaks")
         
         data <- data %>% 
@@ -421,7 +421,7 @@ ggplot_point_col <-
           y = stringr::str_wrap(y_title, y_title_wrap),
           caption = stringr::str_wrap(caption, caption_wrap)
         ) +
-        guides(col = guide_legend(ncol = col_labels_ncol, nrow = col_labels_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap)))
+        guides(col = guide_legend(ncol = col_legend_ncol, nrow = col_legend_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap)))
     }
     else if (mobile == TRUE) {
       plot <- plot +
@@ -660,8 +660,8 @@ ggplot_point_facet <-
 #' @param y_zero_line TRUE or FALSE whether to add a zero reference line to the y axis. TRUE if there are positive and negative values in y_var. Otherwise defaults to FALSE.
 #' @param col_cuts A vector of cuts to colour a numeric variable. If "bin" is selected, the first number in the vector should be either -Inf or 0, and the final number Inf. If "quantile" is selected, the first number in the vector should be 0 and the final number should be 1. Defaults to quartiles. 
 #' @param col_labels_dp Select the appropriate number of decimal places for numeric variable auto legend labels. Defaults to 1.
-#' @param col_labels_ncol The number of columns in the legend. 
-#' @param col_labels_nrow The number of rows in the legend.
+#' @param col_legend_ncol The number of columns in the legend. 
+#' @param col_legend_nrow The number of rows in the legend.
 #' @param col_labels Adjust the colour scale labels through a vector.
 #' @param col_method The method of colouring features, either "bin", "quantile" or "category." If numeric, defaults to "quantile".
 #' @param col_na TRUE or FALSE of whether to show NA values of the colour variable. Defaults to TRUE.
@@ -722,8 +722,8 @@ ggplot_point_col_facet <-
            col_cuts = NULL,
            col_labels_dp = 1,
            col_labels = NULL,
-           col_labels_ncol = NULL,
-           col_labels_nrow = NULL,
+           col_legend_ncol = NULL,
+           col_legend_nrow = NULL,
            col_method = NULL,
            col_na = TRUE,
            col_quantile_by_facet = TRUE,
@@ -780,7 +780,7 @@ ggplot_point_col_facet <-
           else labels <- col_labels
         }
         else if (col_quantile_by_facet == FALSE) { 
-          col_cuts <- quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
+          col_cuts <- stats::quantile(col_var_vctr, probs = col_cuts, na.rm = TRUE)
           if (anyDuplicated(col_cuts) > 0) stop("col_cuts do not provide unique breaks")
           
           data <- data %>% 
@@ -904,7 +904,7 @@ ggplot_point_col_facet <-
         y = stringr::str_wrap(y_title, y_title_wrap),
         caption = stringr::str_wrap(caption, caption_wrap)
       ) +
-      guides(col = guide_legend(ncol = col_labels_ncol, nrow = col_labels_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap))) +
+      guides(col = guide_legend(ncol = col_legend_ncol, nrow = col_legend_nrow, byrow = TRUE, title = stringr::str_wrap(col_title, col_title_wrap))) +
       facet_wrap(vars(!!facet_var), scales = facet_scales, ncol = facet_ncol, nrow = facet_nrow)
 
     
